//
//  SCAdConfiguration.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef enum BehaviorMatrixType {
    behaviorMatrixTypeDefault,
    behaviorMatrixTypeInPage
} BehaviorMatrixType;

@class SCAdEnvironment;

/// This class is used for configuring the advertisement behavior
@interface SCAdConfiguration : NSObject

/// The request url for you advertisement content
@property (nonatomic, copy) NSString *adURL;

/// Text to be displayed on the advertisement as header
@property (nonatomic, copy) NSString* headerText;

/// BundleId of the app
@property (nonatomic, copy) NSString* bundleId;

/// AdvertiserId
@property (nonatomic, copy) NSString* advertisementId;

/// Offset value, when the ad can be skipped (in seconds)
@property (nonatomic, assign) NSInteger skipOffset;

/// To use extended click thru, set this value to true
@property (nonatomic) BOOL useExtendedClickThrough;

/// Use this to enable bitrate calculation, or set desiredBitrate
@property (nonatomic, strong) SCAdEnvironment* environment;

/// Provide uri to custom cascade style sheet for styling the ad view
@property (nonatomic, copy) NSString *customCSSUri;

/// Choose between types inpage and default
@property (nonatomic, assign) BehaviorMatrixType behaviorMatrixType;

/// Use SCCustomCSSUri Info.plist property to globally change this value.
- (NSString*)customCSSUriString;

/// Use SCDisablePlayerScriptUpdate Info.plist property to globally change this value.
/// Bundled javascript core will be used if updates are disabled.
- (BOOL)disableUpdateSDK;

/// Quoted version of adURL
- (NSString*)getAdURLQuoted;

/// The default configuration can be accessed through this static method
+ (SCAdConfiguration*)defaultConfigurationWith:(NSString*)requestURL;

// Default configuration initialized with the given SCAdEnvironment values
+ (SCAdConfiguration*)defaultConfigurationWith:(NSString*)requestURL environment:(SCAdEnvironment*)environment;

/// URL of the default SDK
+ (NSString*)defaultSDKURLString;

/// MobileSDK Version number as String
+ (NSString*)sdkVersionString;
@end
